==> haskell-src-1.0.4.2-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-src.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 haskell-src
version:              1.0.4.2
visibility:           public
id:                   haskell-src-1.0.4.2-2bCKX5Jv0eVgVTbQeocN7
key:                  haskell-src-1.0.4.2-2bCKX5Jv0eVgVTbQeocN7
license:              BSD-3-Clause
maintainer:           Andreas Abel
author:               Simon Marlow, Sven Panne and Noel Winstanley
stability:            stable
synopsis:             Support for manipulating Haskell source code
description:
    The @haskell-src@ package provides support for manipulating Haskell
    source code. The package provides a lexer, parser and
    pretty-printer, and a definition of a Haskell abstract syntax tree
    (AST). Common uses of this package are to parse or generate
    <http://www.haskell.org/onlinereport/ Haskell 98> code.

category:             Language
abi:                  35ac6c0c339d4bd882dfa7639005e386
exposed:              True
exposed-modules:
    Language.Haskell.Lexer Language.Haskell.ParseMonad
    Language.Haskell.ParseUtils Language.Haskell.Parser
    Language.Haskell.Pretty Language.Haskell.Syntax

import-dirs:          /usr/lib/ghc-9.4.8/site-local/haskell-src-1.0.4.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/haskell-src-1.0.4.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/haskell-src-1.0.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-src
hs-libraries:         HShaskell-src-1.0.4.2-2bCKX5Jv0eVgVTbQeocN7
depends:
    array-0.5.4.0 base-4.17.2.1 pretty-1.1.3.6
    syb-0.7.3-B3ujAx0b01UAjArJbq6cUd

haddock-interfaces:   /usr/share/doc/haskell-src/html/haskell-src.haddock
haddock-html:         /usr/share/doc/haskell-src/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-src-1.0.4.2-10-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-src.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 haskell-src
version:              1.0.4.2
visibility:           public
id:                   haskell-src-1.0.4.2-G9tbXQBZKBz1hglnzYVjUV
key:                  haskell-src-1.0.4.2-G9tbXQBZKBz1hglnzYVjUV
license:              BSD-3-Clause
maintainer:           Andreas Abel
author:               Simon Marlow, Sven Panne and Noel Winstanley
stability:            stable
synopsis:             Support for manipulating Haskell source code
description:
    The @haskell-src@ package provides support for manipulating Haskell
    source code. The package provides a lexer, parser and
    pretty-printer, and a definition of a Haskell abstract syntax tree
    (AST). Common uses of this package are to parse or generate
    <http://www.haskell.org/onlinereport/ Haskell 98> code.

category:             Language
abi:                  01d1759d2da875b16c00670422083522
exposed:              True
exposed-modules:
    Language.Haskell.Lexer Language.Haskell.ParseMonad
    Language.Haskell.ParseUtils Language.Haskell.Parser
    Language.Haskell.Pretty Language.Haskell.Syntax

import-dirs:          /usr/lib/ghc-9.4.8/site-local/haskell-src-1.0.4.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/haskell-src-1.0.4.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/haskell-src-1.0.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-src
hs-libraries:         HShaskell-src-1.0.4.2-G9tbXQBZKBz1hglnzYVjUV
depends:
    array-0.5.4.0 base-4.17.2.1 pretty-1.1.3.6
    syb-0.7.3-8wamvTeFqIS3IMzaHn3GXS

haddock-interfaces:   /usr/share/doc/haskell-src/html/haskell-src.haddock
haddock-html:         /usr/share/doc/haskell-src/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
